pub struct ExportedNestEggScripts {
pub installation: NestEggConfigScript,
}Fields
installation: NestEggConfigScriptTrait Implementations
Sourceimpl Clone for ExportedNestEggScripts
impl Clone for ExportedNestEggScripts
Sourcefn clone(&self) -> ExportedNestEggScripts
fn clone(&self) -> ExportedNestEggScripts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExportedNestEggScripts
impl ComposeSchema for ExportedNestEggScripts
Sourceimpl<'de> Deserialize<'de> for ExportedNestEggScripts
impl<'de> Deserialize<'de> for ExportedNestEggScripts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ExportedNestEggScripts
impl Serialize for ExportedNestEggScripts
Sourceimpl ToSchema for ExportedNestEggScripts
impl ToSchema for ExportedNestEggScripts
Sourceimpl Validate for ExportedNestEggScripts
impl Validate for ExportedNestEggScripts
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for ExportedNestEggScripts
impl RefUnwindSafe for ExportedNestEggScripts
impl Send for ExportedNestEggScripts
impl Sync for ExportedNestEggScripts
impl Unpin for ExportedNestEggScripts
impl UnwindSafe for ExportedNestEggScripts